@@ -2,8 +2,8 @@
 #' @description Apply differential uprating to projections of the \code{Sw_amt} variable.
 #' @author Hugh Parsonage and William Young
 #' @param wage A numeric vector to be uprated.
-#' @param from_fy The financial year contemporaneous to wage, which must be a financial year of an available sample file -- in particular, not after 2016-17.
-#' @param to_fy The target of the uprating. Passed to \code{\link{wage_inflator}}.
+#' @param from The financial year contemporaneous to wage, which must be a financial year of an available sample file -- in particular, not after 2016-17.
+#' @param to The target of the uprating. Passed to \code{\link{wage_inflator}}.
 #' @param ... Other arguments passed \code{\link{wage_inflator}}.
 #' @return The vector \code{wage} differentially uprated to \code{to_fy}.
 #' @details See \code{vignette("differential-uprating")}.
@@ -12,27 +12,14 @@
 #' from <- "2013-14"
 #' to <- "2016-17"
 #' differentially_uprate_wage(ws, from, to)
-#' differentially_uprate_wage(ws, from, to) / wage_inflator(ws, from, to)
+#' differentially_uprate_wage(ws, from, to) / (ws * wage_inflator(from, to))
 #' 
-#' # Use a wage series:
-#' if (requireNamespace("taxstats", quietly = TRUE)) {
-#'   library(data.table)
-#'   library(taxstats)
-#'   WageGrowth <- data.table(fy_year = c("2017-18", "2018-19"),
-#'                            r = c(0.0, 0.1))
-#'   Wage201314 <- sample_file_1314[["Sw_amt"]]
-#'   
-#'   data.table(Wage_201314 = Wage201314,
-#'              Wage_201819 = 
-#'                differentially_uprate_wage(Wage201314, 
-#'                                           from_fy = "2013-14",
-#'                                           to_fy = "2018-19",
-#'                                           wage.series = WageGrowth))
-#' }
 #' @export
 
 
-differentially_uprate_wage <- function(wage = 1, from_fy, to_fy, ...){
+differentially_uprate_wage <- function(wage = 1, from, to, ...){
+  from_fy <- from
+  to_fy <- to
   stopifnot(all(from_fy %in% c("2003-04", "2004-05", "2005-06", 
                                "2006-07", "2007-08", "2008-09", 
                                "2009-10", "2010-11", "2011-12", 
@@ -56,7 +43,7 @@ differentially_uprate_wage <- function(wage = 1, from_fy, to_fy, ...){
     setnames(old = "min_salary", new = "wage") %>%
     setkeyv(cols = c("fy.year", "wage")) %>%
     .[input, roll = "nearest"] %>%
-    .[, `_out` := wage * (uprate_factor * (wage_inflator(from_fy = from_fy, to_fy = to_fy, ...) - 1) + 1)] %>%
+    .[, `_out` := wage * (uprate_factor * (wage_inflator(from = from_fy, to = to_fy, ...) - 1) + 1)] %>%
     setkeyv("_order") %>%
     .[["_out"]]
 }
