@@ -1,5 +1,5 @@
 
-all.pkgs <- c("testthat", "data.table", "magrittr", "survey", "zoo")
+all.pkgs <- c("testthat", "data.table", "magrittr", "withr")
 
 
 if (all(vapply(all.pkgs, requireNamespace, logical(1L), quietly = TRUE))) {
@@ -9,7 +9,7 @@ if (all(vapply(all.pkgs, requireNamespace, logical(1L), quietly = TRUE))) {
   library(hutils)
   library(data.table)
   library(magrittr)
-  
+  setDTthreads(1L)
   if (identical(Sys.getenv("CIRCLECI"), "true")) {
     test_check("grattan",
                reporter = JunitReporter$new(file = "junit_result.xml"))
